@@ -38,8 +38,8 @@ public:
     Glib::ustring name;
     Glib::ustring value;
 
-    Attribute(Glib::ustring const & name, Glib::ustring const & value)
-      : name(name), value(value)
+    Attribute(Glib::ustring const & n, Glib::ustring const & v)
+      : name(n), value(v)
       {
       }
   };
@@ -59,8 +59,8 @@ public:
   {
     Glib::ustring const & name;
 
-    AttributeHasName(Glib::ustring const & name)
-      : name(name)
+    AttributeHasName(Glib::ustring const & n)
+      : name(n)
       {
       }
 
@@ -92,6 +92,13 @@ public:
    */
   virtual void parse_memory(const Glib::ustring& contents);
 
+  /** Parse an XML document from raw memory.
+   * @throw exception
+   * @param contents The XML document as an array of bytes.
+   * @param bytes_count The number of bytes in the @a contents array.
+   */
+  void parse_memory_raw(const unsigned char* contents, size_type bytes_count);
+
   /** Parse an XML document from a stream.
    * @throw exception
    * @param in The stream.
@@ -112,6 +119,23 @@ public:
    */
   virtual void parse_chunk(const Glib::ustring& chunk);
 
+  /** Parse a chunk of data.
+   *
+   * @newin2p24
+   *
+   * This lets you pass a document in small chunks, e.g. from a network
+   * connection. The on_* virtual functions are called each time the chunks
+   * provide enough information to advance the parser.
+   *
+   * The first call to parse_chunk will setup the parser. When the last chunk
+   * has been parsed, call finish_chunk_parsing() to finish the parse.
+   *
+   * @throw exception
+   * @param contents The next piece of the XML document as an array of bytes.
+   * @param bytes_count The number of bytes in the @a contents array.
+   */
+  void parse_chunk_raw(const unsigned char* contents, size_type bytes_count);
+
   /** Finish a chunk-wise parse.
    *
    * Call this after the last call to parse_chunk(). Don't use this function with
